pub enum LdpcItem {
Column(usize),
Row(usize),
}Expand description
Whether an LDPC item is a column, one check, or a row, one qubit.
Variants
Column(usize)
A check: its weight is the number of qubits it acts on.
Row(usize)
A qubit: its weight is the number of checks acting on it.